==> alg-feature-2.16.2-sources.jar: cn/com/duiba/nezha/alg/feature/vo/DPAActFeatureDo.java <==
package cn.com.duiba.nezha.alg.feature.vo;

/**
 * @author lijingzhe
 * @description DPA活动
 * @date 2020/6/17
 */
public class DPAActFeatureDo {
    /**
     * key = rid
     */
    private String rid;
    /**
     * 用户ID
     */
    private String deviceId;
    /**
     * 媒体ID
     */
    private Long appId;
    /**
     * 广告位ID
     */
    private Long slotId;
    /**
     * 设备系统类型
     */
    private String ua;
    /**
     * 设备价位
     */
    private String priceSection;
    /**
     * 地域
     */
    private Long areaCode;
    /**
     * 是否组件活动
     */
    private Boolean packageFlag;
    /**
     * 活动ID
     */
    private Long activityId;
    /**
     * 活动奖品标签
     */
    private Long prizeTag;
    /**
     * 活动节日标签
     */
    private Long festivalTag;
    /**
     * 活动类型
     */
    private Long activityType;
    /**
     * 活动设计风格
     */
    private Long designStype;
    /**
     * 皮肤类型
     */
    private Long skinType;
    /**
     * 活动工具ID,一期只测大转盘
     */
    private Long toolId;
    /**
     * 活动工具标签
     */
    private String toolTag;
    /**
     * 主标题ID
     */
    private Long titleId;
    /**
     * 主标题标签
     */
    private String titleTag;
    /**
     * 副标题ID
     */
    private Long subTitleId;
    /**
     * 副标题标签
     */
    private String subTitleTag;
    /**
     * 奖品ID
     */
    private Long prizeId;
    /**
     * 奖品标签
     */
    private String prizeUnitTag;

    public String getRid() {
        return rid;
    }

    public void setRid(String rid) {
        this.rid = rid;
    }

    public String getDeviceId() {
        return deviceId;
    }

    public void setDeviceId(String deviceId) {
        this.deviceId = deviceId;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public Long getSlotId() {
        return slotId;
    }

    public void setSlotId(Long slotId) {
        this.slotId = slotId;
    }

    public String getUa() {
        return ua;
    }

    public void setUa(String ua) {
        this.ua = ua;
    }

    public String getPriceSection() {
        return priceSection;
    }

    public void setPriceSection(String priceSection) {
        this.priceSection = priceSection;
    }

    public Long getAreaCode() {
        return areaCode;
    }

    public void setAreaCode(Long areaCode) {
        this.areaCode = areaCode;
    }

    public Boolean getPackageFlag() {
        return packageFlag;
    }

    public void setPackageFlag(Boolean packageFlag) {
        this.packageFlag = packageFlag;
    }

    public Long getActivityId() {
        return activityId;
    }

    public void setActivityId(Long activityId) {
        this.activityId = activityId;
    }

    public Long getPrizeTag() {
        return prizeTag;
    }

    public void setPrizeTag(Long prizeTag) {
        this.prizeTag = prizeTag;
    }

    public Long getFestivalTag() {
        return festivalTag;
    }

    public void setFestivalTag(Long festivalTag) {
        this.festivalTag = festivalTag;
    }

    public Long getActivityType() {
        return activityType;
    }

    public void setActivityType(Long activityType) {
        this.activityType = activityType;
    }

    public Long getDesignStype() {
        return designStype;
    }

    public void setDesignStype(Long designStype) {
        this.designStype = designStype;
    }

    public Long getSkinType() {
        return skinType;
    }

    public void setSkinType(Long skinType) {
        this.skinType = skinType;
    }

    public Long getToolId() {
        return toolId;
    }

    public void setToolId(Long toolId) {
        this.toolId = toolId;
    }

    public String getToolTag() {
        return toolTag;
    }

    public void setToolTag(String toolTag) {
        this.toolTag = toolTag;
    }

    public Long getTitleId() {
        return titleId;
    }

    public void setTitleId(Long titleId) {
        this.titleId = titleId;
    }

    public String getTitleTag() {
        return titleTag;
    }

    public void setTitleTag(String titleTag) {
        this.titleTag = titleTag;
    }

    public Long getSubTitleId() {
        return subTitleId;
    }

    public void setSubTitleId(Long subTitleId) {
        this.subTitleId = subTitleId;
    }

    public String getSubTitleTag() {
        return subTitleTag;
    }

    public void setSubTitleTag(String subTitleTag) {
        this.subTitleTag = subTitleTag;
    }

    public Long getPrizeId() {
        return prizeId;
    }

    public void setPrizeId(Long prizeId) {
        this.prizeId = prizeId;
    }

    public String getPrizeUnitTag() {
        return prizeUnitTag;
    }

    public void setPrizeUnitTag(String prizeUnitTag) {
        this.prizeUnitTag = prizeUnitTag;
    }
}

==> alg-feature-2.18.0-20200720.072140-10-sources.jar: cn/com/duiba/nezha/alg/feature/vo/DPAActFeatureDo.java <==
package cn.com.duiba.nezha.alg.feature.vo;

/**
 * @author lijingzhe
 * @description DPA活动
 * @date 2020/6/17
 */
public class DPAActFeatureDo {
    /**
     * key = rid
     */
    private String rid;
    /**
     * 用户ID
     */
    private String deviceId;
    /**
     * 媒体ID
     */
    private Long appId;
    /**
     * 广告位ID
     */
    private Long slotId;
    /**
     * 设备系统类型
     */
    private String ua;
    /**
     * 设备价位
     */
    private String priceSection;
    /**
     * 地域
     */
    private Long areaCode;
    /**
     * 活动/组件包ID
     */
    private PackageIdDo packageIdDo = new PackageIdDo();

    public String getRid() {
        return rid;
    }

    public void setRid(String rid) {
        this.rid = rid;
    }

    public String getDeviceId() {
        return deviceId;
    }

    public void setDeviceId(String deviceId) {
        this.deviceId = deviceId;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public Long getSlotId() {
        return slotId;
    }

    public void setSlotId(Long slotId) {
        this.slotId = slotId;
    }

    public String getUa() {
        return ua;
    }

    public void setUa(String ua) {
        this.ua = ua;
    }

    public String getPriceSection() {
        return priceSection;
    }

    public void setPriceSection(String priceSection) {
        this.priceSection = priceSection;
    }

    public Long getAreaCode() {
        return areaCode;
    }

    public void setAreaCode(Long areaCode) {
        this.areaCode = areaCode;
    }

    public PackageIdDo getPackageIdDo() {
        return packageIdDo;
    }

    public void setPackageIdDo(PackageIdDo packageIdDo) {
        this.packageIdDo = packageIdDo;
    }
}
